@@ -10,5 +10,5 @@ from scripts.mining.reddit_self import parse_reddit_selftext
 from scripts.move_list import move_list
 from scripts.optimize_db import optimize_db
 from scripts.redownload import redownload
-from scripts.scatter import scatter
+from scripts.scatter import scatter, scatter_usage
 from scripts.streaming_tab_loader import streaming_tab_loader
