@@ -8,7 +8,7 @@ def optimize_db():
     parser = argparse.ArgumentParser()
     parser.add_argument("--verbose", "-v", action="count", default=0)
     parser.add_argument("--db", "-db", help=argparse.SUPPRESS)
-    parser.add_argument("database", nargs="?", default="video.db")
+    parser.add_argument("database")
     args = parser.parse_args()
     if args.db:
         args.database = args.db
