@@ -7,10 +7,10 @@ from xklb import consts, db, player, tube_backend, utils
 from xklb.consts import SC
 from xklb.player import get_ordinal_media, mark_media_deleted, override_sort
 from xklb.subtitle import externalize_subtitle
-from xklb.utils import cmd, human_to_bytes, log
+from xklb.utils import cmd, log
 
 
-def usage(action, default_db) -> str:
+def usage(action) -> str:
     return f"""library {action} [database] [optional args]
 
     Control playback:
@@ -19,10 +19,6 @@ def usage(action, default_db) -> str:
         Create global shortcuts in your desktop environment by sending commands to mpv_socket:
         echo 'playlist-next force' | socat - /tmp/mpv_socket
 
-    If not specified, {action} will try to read {default_db} in the working directory:
-        library {action}
-        library {action} ./my/other/database/is-a/db.db
-
     Override the default player (mpv):
         library does a lot of things to try to automatically use your preferred media player
         but if it doesn't guess right you can make it explicit:
@@ -44,11 +40,16 @@ def usage(action, default_db) -> str:
         library {action} --partial       # play newest first
         library {action} --partial old   # play oldest first
         library {action} -P o            # equivalent
-        library {action} -P fo           # use file creation time instead of modified time
-
         library {action} -P p            # sort by progress / duration
         library {action} -P s            # skip partially watched (only show unseen)
 
+        The default time used is "last-viewed" (ie. the most recent time you closed the video)
+        If you want to use the "first-viewed" time (ie. the very first time you opened the video)
+        library {action} -P f            # use watch_later file creation time instead of modified time
+
+        You can combine most of these options, though some will be overridden by others.
+        library {action} -P fo           # this means "show the oldest videos using the time I first opened them"
+
     Print instead of play:
         library {action} --print --limit 10  # print the next 10 files
         library {action} -p -L 10  # print the next 10 files
@@ -120,7 +121,7 @@ def usage(action, default_db) -> str:
 
     Offset the play queue:
         You can also offset the queue. For example if you want to skip one or ten media:
-        library {action} -S 10  # offset ten from the top of an ordered query
+        library {action} --skip 10        # offset ten from the top of an ordered query
 
     Repeat
         library {action}                  # listen to 120 random songs (DEFAULT_PLAY_QUEUE)
@@ -142,9 +143,12 @@ def usage(action, default_db) -> str:
         library {action} -O -s 'path : "mad max"' # add "quotes" to be more strict
 
         Double spaces are parsed as one space
-        -s '  ost'        # will match OST and not ghost
-        -s toy story      # will match '/folder/toy/something/story.mp3'
-        -s 'toy  story'   # will match more strictly '/folder/toy story.mp3'
+        library {action} -s '  ost'        # will match OST and not ghost
+        library {action} -s toy story      # will match '/folder/toy/something/story.mp3'
+        library {action} -s 'toy  story'   # will match more strictly '/folder/toy story.mp3'
+
+        You can search without -s but it must directly follow the database due to how argparse works
+        library {action} my.db searching for something
 
     Constrain media by arbitrary SQL expressions:
         library {action} --where audio_count = 2  # media which have two audio tracks
@@ -166,9 +170,9 @@ def usage(action, default_db) -> str:
 
     Constrain media to file size (in megabytes):
         library {action} --size 20
-        library {action} -z 6  # 6 MB ±10 percent (ie. between 5 and 7 MB)
-        library {action} -z-6  # less than 6 MB
-        library {action} -z+6  # more than 6 MB
+        library {action} -S 6  # 6 MB ±10 percent (ie. between 5 and 7 MB)
+        library {action} -S-6  # less than 6 MB
+        library {action} -S+6  # more than 6 MB
 
     Constrain media by time_created / time_played / time_deleted / time_modified:
         library {action} --created-within '3 days'
@@ -246,18 +250,18 @@ def parse_args_sort(args, action):
     args.sort = "\n        , ".join(args.sort).replace(",,", ",")
 
 
-def parse_args(action, default_db, default_chromecast="") -> argparse.Namespace:
+def parse_args(action, default_chromecast=None) -> argparse.Namespace:
     DEFAULT_PLAYER_ARGS_SUB = ["--speed=1"]
     DEFAULT_PLAYER_ARGS_NO_SUB = ["--speed=1.46"]
 
-    parser = argparse.ArgumentParser(prog="library " + action, usage=usage(action, default_db))
+    parser = argparse.ArgumentParser(prog="library " + action, usage=usage(action))
 
     parser.add_argument("--play-in-order", "-O", action="count", default=0, help=argparse.SUPPRESS)
     parser.add_argument("--sort", "-u", nargs="+", help=argparse.SUPPRESS)
     parser.add_argument("--random", "-r", action="store_true", help=argparse.SUPPRESS)
 
     parser.add_argument("--where", "-w", nargs="+", action="extend", default=[], help=argparse.SUPPRESS)
-    parser.add_argument("--include", "-s", "--search", nargs="+", action="extend", default=[], help=argparse.SUPPRESS)
+    parser.add_argument("--include", "-s", nargs="+", action="extend", default=[], help=argparse.SUPPRESS)
     parser.add_argument("--exclude", "-E", "-e", nargs="+", action="extend", default=[], help=argparse.SUPPRESS)
 
     parser.add_argument("--created-within", help=argparse.SUPPRESS)
@@ -269,7 +273,9 @@ def parse_args(action, default_db, default_chromecast="") -> argparse.Namespace:
     parser.add_argument("--deleted-within", help=argparse.SUPPRESS)
     parser.add_argument("--deleted-before", help=argparse.SUPPRESS)
 
-    parser.add_argument("--chromecast-device", "--cast-to", "-t", default=default_chromecast, help=argparse.SUPPRESS)
+    parser.add_argument(
+        "--chromecast-device", "--cast-to", "-t", default=default_chromecast or "", help=argparse.SUPPRESS
+    )
     parser.add_argument("--chromecast", "--cast", "-c", action="store_true", help=argparse.SUPPRESS)
     parser.add_argument("--cast-with-local", "-wl", action="store_true", help=argparse.SUPPRESS)
     parser.add_argument("--loop", action="store_true", help=argparse.SUPPRESS)
@@ -331,15 +337,12 @@ def parse_args(action, default_db, default_chromecast="") -> argparse.Namespace:
     parser.add_argument("--ignore-errors", "--ignoreerrors", "-i", action="store_true")
     parser.add_argument("--verbose", "-v", action="count", default=0)
 
-    parser.add_argument(
-        "database",
-        nargs="?",
-        default=default_db,
-        help=f"Database file. If not specified a generic name will be used: {default_db}",
-    )
-    args = parser.parse_args()
+    parser.add_argument("database")
+    parser.add_argument("search", nargs="*")
+    args = parser.parse_intermixed_args()
     args.action = action
     args.defaults = []
+    args.include += args.search
 
     if args.db:
         args.database = args.db
@@ -645,25 +648,25 @@ def process_playqueue(args) -> None:
 
 
 def watch() -> None:
-    args = parse_args(SC.watch, "video.db", default_chromecast="Living Room TV")
+    args = parse_args(SC.watch, default_chromecast="Living Room TV")
     process_playqueue(args)
 
 
 def listen() -> None:
-    args = parse_args(SC.listen, "audio.db", default_chromecast="Xylo and Orchestra")
+    args = parse_args(SC.listen, default_chromecast="Xylo and Orchestra")
     process_playqueue(args)
 
 
 def filesystem() -> None:
-    args = parse_args(SC.filesystem, "fs.db")
+    args = parse_args(SC.filesystem)
     process_playqueue(args)
 
 
 def read() -> None:
-    args = parse_args(SC.read, "text.db")
+    args = parse_args(SC.read)
     process_playqueue(args)
 
 
 def view() -> None:
-    args = parse_args(SC.view, "image.db")
+    args = parse_args(SC.view)
     process_playqueue(args)
